.. _glossary:

********
Glossary
********

.. glossary::

    SFChat server
        SFChat server provides connection between chat participants. It works like a phone or an internet provider do.

    invitation code
        A unique identifier alphanumeric string with length 24 characters. It is used to identify chat. Such identifier is _id in MongoDB chat collection. Therefore an invitation code must be sent through the secure channel e.g mobile phone, email, etc. 

    system message
        A type of message that is sent to participant by SFChat to inform notice of about a chat status, errors, etc.

    long pulling
        Is the FrontEnd technique that is used to reduce the number of request to the server

    chat creator
        A person who creates a new chat and sends an invitation code to  another participant

    chat joiner
        A person who join the chat conversation by using an invitation code

    chat token
        The same value as the invitation code

    user token
        A unique identifier of user. This identifier is generated during the authorization process. It helps to identify the user and the chat.  It’s generated by ``ObjectId()`` in MongoDB. 

    message token
        A unique identifier of message. It’s used for handle message delivery process.  It’s generated by "ObjectId()" in MongoDB.

